'''
LeetCode Problem 1: Two Sum
Given an array of integers nums and an integer target, return indices of the two numbers such that they add up to target.
You may assume that each input would have exactly one solution, and you may not use the same element twice.
'''
def twoSum(nums, target):
      hash_map = {}
      for i, num in enumerate(nums):
          difference = target - num
          if difference in hash_map:
            return [hash_map[difference], i]
          hash_map[num] = i
      return []


# setup.py

from setuptools import setup, find_packages

setup(
    name="shaksz",
    version="0.1.1",
    packages=find_packages(),
    install_requires=[],
    author="Varun Verma",
    author_email="vermavarun@outlook.com",
    description="All coding and design solutions as package",
    long_description=open('README.md').read(),
    long_description_content_type="text/markdown",
    url="https://github.com/vermavarun/shaksz",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)
